# Cloud Services

PIP package to provide cloud services.

## Package installation
- Installation
    ```shell
    $ pip3 install flask-feature-flag
    ```

## Configuration

Define the following environment variables:

* (str) Provider. Allowed: [aws, ]

        ```
        CLOUD_SERVICES_PROVIDER=
        ```

* (str) Region. Example: 'us-west-2'

        ```
        CLOUD_SERVICES_REGION=
        ```
